@@ -1,5 +1,10 @@
 from .lrng import LabeledRange, LabeledRanges
 from .numba import coalesce, label_range, relevant_labels
 name = 'lrng'
-version = '0.0.8'
+
+major = 1
+minor = 0
+patch = 0
+
+version = '{}.{}.{}'.format(major, minor, patch)
 description = 'Labeled Ranges'
